#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

# Example output
"""
<name>|<state>|<status>|<stackingHealth>|<consistencyStatus>
<<<hpe_oneview_log_interconnects:sep(124)>>>
LEG-SVA-LIG-MPO_withIS|Unknown|OK|BiConnected|CONSISTENT
"""

from .agent_based_api.v1 import *

info_list = ["name", "state", "status", "stackingHealth", "consistencyStatus"]
state_map = {
    0: State.OK,
    1: State.WARN,
    2: State.CRIT,
    3: State.UNKNOWN
}

def parse_hpe_oneview_log_interconnects(string_table):
    output = []
    for interconnect in string_table:
        info_map = dict(zip(info_list, interconnect))
        output.append(info_map)
    return output

register.agent_section(
    name="hpe_oneview_log_interconnects",
    parse_function=parse_hpe_oneview_log_interconnects
)

def discovery_hpe_oneview_log_interconnects(section):
    for interconnect in section:
        yield Service(item=interconnect["name"])


def check_hpe_oneview_log_interconnects(item, params, section):
    map_status = params["map_status"]
    map_consistencyStatus = params["map_consistencyStatus"]
    map_stackingHealth = params["map_stackingHealth"]

    for interconnect in section:
        if interconnect["name"] == item:

            s= state_map[map_status[interconnect["status"]]] 
            yield Result(state=s, summary="Status: {}".format(interconnect["status"]))

            s= state_map[map_consistencyStatus[interconnect["consistencyStatus"]]]
            yield Result(state=s, summary="consistencyStatus: {}".format(interconnect["consistencyStatus"]))

            s= state_map[map_stackingHealth[interconnect["stackingHealth"]]]
            yield Result(state=s, summary="stackingHealth: {}".format(interconnect["stackingHealth"]))





register.check_plugin(
    name="hpe_oneview_log_interconnects",
    service_name="Logical Interconnect %s",
    check_ruleset_name="hpe_oneview_log_interconnects",
    check_default_parameters={
        "map_status": {
            "OK": 0,
            "Disabled": 1,
            "Warning": 1,
            "Critical": 2,
            "Unknown": 3
            },
        "map_consistencyStatus": {
            "CONSISTENT": 0,
            "NOT_CONSISTENT": 2
        },
        "map_stackingHealth": {
            "BiConnected": 0,
            "Connected": 0,
            "Disconnected": 1,
            "DisconnectedShutdown": 2,
            "NotApplicable": 3,
            "Unknown": 3
            }
        },
    discovery_function=discovery_hpe_oneview_log_interconnects,
    check_function=check_hpe_oneview_log_interconnects,
)