#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2020  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    Tuple,
    MonitoringState
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersApplications,
)


def _parameter_valuespec_hpe_oneview_log_interconnects():
    return Dictionary(elements=[
        ("map_status",
         Dictionary(
             title=_("Map Attribute 'Status'"),
             elements=[
                 ("OK", MonitoringState(title=_("OK"), default_value=0)),
                 ("Disabled", MonitoringState(title=_("Disabled"), default_value=1)),
                 ("Warning", MonitoringState(title=_("Warning"), default_value=1)),
                 ("Critical", MonitoringState(title=_("Critical"), default_value=2)),
                 ("Unknown", MonitoringState(title=_("Unknown"), default_value=3)),
             ],
             optional_keys=False,
         )),
        ("map_consistencyStatus",
         Dictionary(
             title=_("Map Attributed 'consistencyStatus'"),
             elements=[
                ("CONSISTENT", MonitoringState(title=_("CONSISTENT"), default_value=0)),
                ("NOT_CONSISTENT", MonitoringState(title=_("NOT_CONSISTENT"), default_value=0)),
            ],
            optional_keys=False,
        )),
        ("map_stackingHealth",
         Dictionary(
             title=_("Map Attribute 'stackingHealth'"),
             elements=[
                 ("BiConnected", MonitoringState(title=_("BiConnected"), default_value=0)),
                 ("Connected", MonitoringState(title=_("Connected"), default_value=0)),
                 ("Disconnected", MonitoringState(title=_("Disconnected"), default_value=1)),
                 ("DisconnectedShutdown", MonitoringState(title=_("DisconnectedShutdown"), default_value=2)),
                 ("NotApplicable", MonitoringState(title=_("NotApplicable"), default_value=3)),
                 ("Unknown", MonitoringState(title=_("Unknown"), default_value=3)),
             ],
             optional_keys=False,
         )),
    ],)

rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="hpe_oneview_log_interconnects",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_hpe_oneview_log_interconnects,
        title=lambda: _("HPE OneView Logical Interconnect States"),
    ))
